@@ -43,6 +43,7 @@
 #include "releaseinputdialog.h"
 #include "cvslogdialog.h"
 #include "editorsdialog.h"
+#include "annotatedialog.h"
 
 #include "changelog.h"
 #include "cvsoptions.h"
@@ -476,10 +477,59 @@ void CvsServicePartImpl::add( const KURL::List& urlList, bool binary )
 
 ///////////////////////////////////////////////////////////////////////////////
 
+void CvsServicePartImpl::annotate( const KURL::List& urlList )
+{
+    kdDebug(9006) << k_funcinfo << endl;
+
+    if (!prepareOperation( urlList, opAnnotate ))
+        return;
+
+    //get the directory of the file we want to annotate
+    QString tagFilename = URLUtil::directory(projectDirectory()+"/"+fileList()[0]);
+    //CVS stores tag information in the ./CVS/Tag file
+    tagFilename += "/CVS/Tag";
+
+
+    //Check if such a Tag file exists, and try to read the tag/branch from it
+    QFile fileTag(tagFilename);
+    QString strRev = "";  //default revision is empty ...
+    if (fileTag.exists()) { //... but if there is a Tag file, we get the revision from there
+        if ( fileTag.open( IO_ReadOnly ) ) {
+            QTextStream stream( &fileTag );
+            QString line;
+            line = stream.readLine();
+            if (line.startsWith("T")) { //the line always starts with a "T"...
+                strRev = line.right(line.length()-1); //...and after this there is the tag name
+                kdDebug(9006) << "The found revision is:  >>" << strRev << "<<" <<endl;
+            }
+            fileTag.close();
+        }
+    }
+    
+    AnnotateDialog * f = new AnnotateDialog( m_cvsService );
+    f->show();
+    //the dialog will do all the work, just give him the file and the revision to start with
+    f->startFirstAnnotate( fileList()[0], strRev );
+
+    doneOperation();
+}
+
+///////////////////////////////////////////////////////////////////////////////
+
 void CvsServicePartImpl::unedit( const KURL::List& urlList)
 {
     kdDebug(9006) << k_funcinfo << endl;
 
+    int s = KMessageBox::questionYesNo( 0,
+        i18n("Do you really want to unedit the selected files?"),
+        i18n("CVS - Unedit Files"),
+        i18n("Unedit"),
+        i18n("Do Not Unedit"),
+        "askUneditingFiles" );
+    if (s == KMessageBox::No) {
+        return;
+    }
+
     if (!prepareOperation( urlList, opUnEdit ))
         return;
 
@@ -592,8 +642,11 @@ void CvsServicePartImpl::diff( const KURL::List& urlList )
 
     if (!prepareOperation( urlList, opDiff ))
         return;
+    
+    CVSDir cvsdir = CVSDir( urlList[0].directory() );
+    CVSEntry entry = cvsdir.fileStatus( urlList[0].fileName() );
 
-    DiffDialog dlg;
+    DiffDialog dlg(entry);
     if (dlg.exec() != QDialog::Accepted)
         return;
 
@@ -787,8 +840,12 @@ void CvsServicePartImpl::addFilesToProject( const QStringList &filesToAdd )
     int s = KMessageBox::questionYesNo( 0,
         i18n("Do you want to be added to CVS repository too?"),
         i18n("CVS - New Files Added to Project"),
-        KStdGuiItem::yes(),
-        KStdGuiItem::no(),
+#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
+        KStdGuiItem::add(),
+#else
+        i18n( "Add Files"),
+#endif
+        i18n("Do Not Add"),
         i18n("askWhenAddingNewFiles") );
     if (s == KMessageBox::Yes)
     {
@@ -820,7 +877,7 @@ void CvsServicePartImpl::removedFilesFromProject(const QStringList &filesToRemov
     int s = KMessageBox::warningContinueCancel( 0,
         i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too."),
         i18n("CVS - Files Removed From Project"),
-        KGuiItem( "&Delete", "editdelete", "Delete item(s)"),
+        KGuiItem( i18n( "&Delete" ), "editdelete", i18n( "Delete item(s)" )),
         i18n("askWhenRemovingFiles") );
 #endif
     if (s == KMessageBox::Continue)
